What’s new in version 1.2.0
===========================
Version available since November 28th 2022


Changes
-------

- Non-periodic ODE systems must be represented with a Python class instead of a function.
- For periodic ODE systems, a "commande" method must be written by the user to detect configurations changes.

New Features
------------

- Average and RMS values can be extracted for non-periodic ODE systems.
- RMS value can be extracted for periodic ODE systems.
- When optimization does not converge, new initial random point is printed.


Contributors
------------
Lucas Agobert
